@@ -88,6 +88,34 @@ class IRenderer(Interface):
         """
 
 
+class IRenderable(Interface):
+    def renderer(name):
+        """
+        Return the render function associated with the given name.
+
+        @type name: C{str}
+        @param name: The value of a render directive encountered in the
+            document returned by a call to L{IRenderable.render}.
+
+        @return: A two-argument callable which will be invoked with the request
+            being responded to and the tag object on which the render directive
+            was encountered.
+        """
+
+
+    def render(request):
+        """
+        Get the document for this L{IRenderable}.
+
+        @type request: L{IRequest} provider or L{NoneType}
+        @param request: The request in response to which this method is being
+            invoked.
+
+        @return: An object which can be flattened.
+        """
+
+
+
 class IRendererFactory(Interface):
     """A renderer factory is capable of taking a renderer directive (a string)
     and returning a callable which when called, will render a portion of DOM.
@@ -272,8 +300,19 @@ class IRequest(IComponentized):
     @type args: A mapping of strings (the argument names) to lists of values.
                 i.e., ?foo=bar&foo=baz&quux=spam results in
                 {'foo': ['bar', 'baz'], 'quux': ['spam']}.
-    @ivar received_headers: All received headers
+    @ivar received_headers: All received headers.
     """
+    method = Attribute("The HTTP method that was used.")
+    uri = Attribute("The full URI that was requested (includes arguments).")
+    path = Attribute("The path only (arguments not included).")
+    prepath = Attribute("Path segments that have already been handled.")
+    postpath = Attribute("Path segments still to be handled.")
+    args = Attribute("All of the arguments, including URL and POST arguments.")
+    received_headers = Attribute("All received headers.")
+    deferred = Attribute("Fired once request processing is finished.")
+    client = Attribute("The client that sent this request.")
+    content = Attribute("File-like object containing the request body.")
+
     # Methods for received request
     def getHeader(key):
         """Get a header that was sent from the network.
@@ -429,6 +468,17 @@ class IRequest(IComponentized):
         This method is experimental.
         """
 
+
+    def notifyFinish(success):
+        """
+        Return a deferred that fires when the request is finished.
+
+        The deferred will fire with C{None} if the request finished
+        successfully, or with the error that caused it to be unsuccessful.
+        """
+
+
+
 class ISerializable(Interface):
     """DEPRECATED. Use nevow.flat.registerFlattener instead of registering
     an ISerializable adapter.
@@ -489,12 +539,12 @@ class IDocFactory(Interface):
     actually rendered.
     """
 
-    def load(ctx=None, preprocessors=()):
+    def load(ctx=None, preprocessors=(), precompile=None):
         """
         Load a template and return a stan document tree.
 
         @param preprocessors: An iterable of one-argument callables which will
-        be given the stan document tree to transform before it is compiled.
+            be given the stan document tree to transform before it is compiled.
         """
 
 
